@@ -1,6 +1,6 @@
 package Hubot::Message;
 {
-  $Hubot::Message::VERSION = '0.1.8';
+  $Hubot::Message::VERSION = '0.1.9';
 }
 use Moose;
 use namespace::autoclean;
@@ -37,7 +37,7 @@ __PACKAGE__->meta->make_immutable;
 
 package Hubot::TextMessage;
 {
-  $Hubot::TextMessage::VERSION = '0.1.8';
+  $Hubot::TextMessage::VERSION = '0.1.9';
 }
 use Moose;
 use namespace::autoclean;
@@ -65,7 +65,7 @@ __PACKAGE__->meta->make_immutable;
 
 package Hubot::EnterMessage;
 {
-  $Hubot::EnterMessage::VERSION = '0.1.8';
+  $Hubot::EnterMessage::VERSION = '0.1.9';
 }
 use Moose;
 use namespace::autoclean;
@@ -76,7 +76,7 @@ __PACKAGE__->meta->make_immutable;
 
 package Hubot::LeaveMessage;
 {
-  $Hubot::LeaveMessage::VERSION = '0.1.8';
+  $Hubot::LeaveMessage::VERSION = '0.1.9';
 }
 use Moose;
 use namespace::autoclean;
@@ -87,15 +87,29 @@ __PACKAGE__->meta->make_immutable;
 
 package Hubot::WhisperMessage;
 {
-  $Hubot::WhisperMessage::VERSION = '0.1.8';
+  $Hubot::WhisperMessage::VERSION = '0.1.9';
 }
 use Moose;
 use namespace::autoclean;
 extends 'Hubot::TextMessage';
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+package Hubot::NoticeMessage;
+{
+  $Hubot::NoticeMessage::VERSION = '0.1.9';
+}
+use Moose;
+use namespace::autoclean;
+extends 'Hubot::TextMessage';
+__PACKAGE__->meta->make_immutable;
+
+1;
 
 package Hubot::CatchAllMessage;
 {
-  $Hubot::CatchAllMessage::VERSION = '0.1.8';
+  $Hubot::CatchAllMessage::VERSION = '0.1.9';
 }
 use Moose;
 use namespace::autoclean;
